@@ -7,6 +7,8 @@ from .labelers.data_labelers import train_structured_labeler, DataLabeler, \
                                     UnstructuredDataLabeler
 from .validators.base_validators import Validator
 from .version import __version__
+from . import settings
+
 
 try:
     import snappy
@@ -22,3 +24,9 @@ except ImportError:
         '\tsudo apt-get -y install libsnappy-dev`\n',
         ImportWarning
     )
+
+def set_seed(seed=None):
+    # also check it's an integer
+    if seed is not None and (not isinstance(seed, int) or seed < 0):
+        raise ValueError("Seed should be a non-negative integer.")
+    settings._seed = seed
