@@ -3,6 +3,7 @@ import operator
 import numpy as np
 
 from . import BaseColumnProfiler
+from . import utils
 from ..labelers.data_labelers import DataLabeler
 from .profiler_options import DataLabelerOptions
 
@@ -238,6 +239,30 @@ class DataLabelerColumn(BaseColumnProfiler):
         }
         return profile
 
+    def diff(self, other_profile, options=None):
+        """
+        Generates the differences between the orders of two DataLabeler columns
+
+        :return: Dict containing the differences between orders in their
+        appropriate output formats
+        :rtype: dict
+        """
+        differences = super().diff(other_profile, options)
+
+        labels = self.data_label.split('|')
+        avg_preds = self.avg_predictions
+        label_rep = self.label_representation
+        other_labels = other_profile.data_label.split('|')
+        other_avg_preds = other_profile.avg_predictions
+        other_label_rep = other_profile.label_representation
+
+        differences = {
+            "data_label": utils.find_diff_of_lists_and_sets(labels, other_labels),
+            "avg_predictions": utils.find_diff_of_dicts(avg_preds, other_avg_preds),
+            "label_representation": utils.find_diff_of_dicts(label_rep, other_label_rep)
+        }
+        return differences
+
     @BaseColumnProfiler._timeit(name='data_labeler_predict')
     def _update_predictions(self, df_series, prev_dependent_properties=None,
                             subset_properties=None):
