@@ -477,15 +477,15 @@ class PrecisionOptions(BooleanOption):
         errors = super()._validate_helper(variable_path=variable_path)
         if self.sample_ratio is not None:
             if not isinstance(self.sample_ratio, float) \
-               and not isinstance(self.sample_ratio, int):
+                    and not isinstance(self.sample_ratio, int):
                 errors.append("{}.sample_ratio must be a float."
-                              .format(variable_path))                
+                              .format(variable_path))
             if (isinstance(self.sample_ratio, float) \
-               or isinstance(self.sample_ratio, int)) \
-               and (self.sample_ratio < 0 or self.sample_ratio > 1.0):
+                or isinstance(self.sample_ratio, int)) \
+                    and (self.sample_ratio < 0 or self.sample_ratio > 1.0):
                 errors.append("{}.sample_ratio must be a float between 0 and 1."
-                              .format(variable_path))                
-        
+                              .format(variable_path))
+
         return errors
 
 
@@ -690,7 +690,7 @@ class OrderOptions(BaseInspectorOptions):
         :return: list of errors (if raise_error is false)
         :rtype: list(str)
         """
-        return super()._validate_helper(variable_path) 
+        return super()._validate_helper(variable_path)
 
 
 class CategoricalOptions(BaseInspectorOptions):
@@ -716,6 +716,42 @@ class CategoricalOptions(BaseInspectorOptions):
         return super()._validate_helper(variable_path)
 
 
+class CorrelationOptions(BaseInspectorOptions):
+
+    def __init__(self, is_enabled=False, columns=None):
+        """
+        Options for the Correlation between Columns
+
+        :ivar is_enabled: boolean option to enable/disable.
+        :vartype is_enabled: bool
+        :ivar columns: Columns considered to calculate correlation
+        :vartype columns: list()
+        """
+        BaseInspectorOptions.__init__(self, is_enabled=is_enabled)
+        self.columns = columns
+
+    def _validate_helper(self, variable_path='CorrelationOptions'):
+        """
+        Validates the options do not conflict and cause errors.
+
+        :param variable_path: current path to variable set.
+        :type variable_path: str
+        :return: list of errors (if raise_error is false)
+        :rtype: list(str)
+        """
+        errors = super()._validate_helper(variable_path=variable_path)
+
+        if (self.columns is not None and
+                (not isinstance(self.columns, list)
+                 or len(self.columns) <= 1
+                 or not all(isinstance(item, str)
+                            for item in self.columns))):
+            errors.append("{}.columns must be None "
+                          "or list of strings "
+                          "with at least two elements.".format(variable_path))
+        return errors
+
+
 class DataLabelerOptions(BaseInspectorOptions):
 
     def __init__(self):
@@ -763,7 +799,7 @@ class DataLabelerOptions(BaseInspectorOptions):
         :rtype: dict
         """
         props = {k: copy.deepcopy(v)
-                 for k,v in self.__dict__.items() if k != 'data_labeler_object'}
+                 for k, v in self.__dict__.items() if k != 'data_labeler_object'}
         props['data_labeler_object'] = self.data_labeler_object
         return props
 
@@ -805,7 +841,8 @@ class DataLabelerOptions(BaseInspectorOptions):
 class TextProfilerOptions(BaseInspectorOptions):
 
     def __init__(self, is_enabled=True, is_case_sensitive=True,
-                 stop_words=None):
+                 stop_words=None, top_k_chars=None,
+                 top_k_words=None):
         """
         Constructs the TextProfilerOption object with default values.
 
@@ -815,6 +852,10 @@ class TextProfilerOptions(BaseInspectorOptions):
         :vartype is_case_sensitive: bool
         :ivar stop_words: option set for stop words.
         :vartype stop_words: Union[None, list(str)]
+        :ivar top_k_chars: option set for number of top common characters.
+        :vartype top_k_chars: Union[None, int]
+        :ivar top_k_words: option set for number of top common words.
+        :vartype top_k_words: Union[None, int]
         :ivar words: option set for word update.
         :vartype words: BooleanOption
         :ivar vocab: option set for vocab update.
@@ -823,8 +864,10 @@ class TextProfilerOptions(BaseInspectorOptions):
         super().__init__(is_enabled=is_enabled)
         self.is_case_sensitive = is_case_sensitive
         self.stop_words = stop_words
-        self.words = BooleanOption(is_enabled=True)
+        self.top_k_chars = top_k_chars
+        self.top_k_words = top_k_words
         self.vocab = BooleanOption(is_enabled=True)
+        self.words = BooleanOption(is_enabled=True)
 
     def _validate_helper(self, variable_path='TextProfilerOptions'):
         """
@@ -851,15 +894,26 @@ class TextProfilerOptions(BaseInspectorOptions):
             errors.append("{}.stop_words must be None "
                           "or list of strings.".format(variable_path))
 
-        if not isinstance(self.words, BooleanOption):
-            errors.append("{}.words must be a BooleanOption "
-                          "object."
-                          .format(variable_path))
+        if (self.top_k_chars is not None and
+                (not isinstance(self.top_k_chars, int) or self.top_k_chars <= 0)):
+            errors.append("{}.top_k_chars must be None "
+                          "or positive integer.".format(variable_path))
+
+        if (self.top_k_words is not None and
+                (not isinstance(self.top_k_words, int) or self.top_k_words <= 0)):
+            errors.append("{}.top_k_words must be None "
+                          "or positive integer.".format(variable_path))
 
         if not isinstance(self.vocab, BooleanOption):
             errors.append("{}.vocab must be a BooleanOption "
                           "object."
                           .format(variable_path))
+
+        if not isinstance(self.words, BooleanOption):
+            errors.append("{}.words must be a BooleanOption "
+                          "object."
+                          .format(variable_path))
+
         return errors
 
 
@@ -883,6 +937,8 @@ class StructuredOptions(BaseOption):
         :vartype category: CategoricalOptions
         :ivar data_labeler: option set for data_labeler profiling.
         :vartype data_labeler: DataLabelerOptions
+        :ivar correlation: option set for correlation profiling.
+        :vartype correlation: CorrelationOptions
         """
         self.multiprocess = BooleanOption()
         self.int = IntOptions()
@@ -892,6 +948,7 @@ class StructuredOptions(BaseOption):
         self.order = OrderOptions()
         self.category = CategoricalOptions()
         self.data_labeler = DataLabelerOptions()
+        self.correlation = CorrelationOptions()
 
     @property
     def enabled_profiles(self):
@@ -924,7 +981,8 @@ class StructuredOptions(BaseOption):
             ('text', TextOptions),
             ('order', OrderOptions),
             ('category', CategoricalOptions),
-            ('data_labeler', DataLabelerOptions)
+            ('data_labeler', DataLabelerOptions),
+            ('correlation', CorrelationOptions)
         ])
 
         for column in self.properties:
