@@ -1,4 +1,4 @@
-from collections import defaultdict
+from collections import defaultdict, Counter
 import itertools
 import re
 import warnings
@@ -22,7 +22,7 @@ class TextProfiler(object):
         self.name = name
         self.sample_size = 0
         self.times = defaultdict(float)
-        self.vocab = set()
+        self.vocab_count = Counter()
         self.word_count = defaultdict(int)
         self.metadata = dict()
 
@@ -100,12 +100,33 @@ class TextProfiler(object):
         if options and options.stop_words is not None:
             self._stop_words = options.stop_words
 
+        self._top_k_chars = None
+        if options:
+            self._top_k_chars = options.top_k_chars
+
+        self._top_k_words = None
+        if options:
+            self._top_k_words = options.top_k_words
+
         self.__calculations = {
             "vocab": TextProfiler._update_vocab,
             "words": TextProfiler._update_words,
         }
         BaseColumnProfiler._filter_properties_w_options(self.__calculations, options)
 
+    @staticmethod
+    def _merge_vocab(vocab_count1, vocab_count2):
+        """
+        Merges the vocab counts of two TextProfiler profiles
+
+        :param vocab_count1: vocab count of the first profile
+        :param vocab_count2: vocab count of the second profile
+        :type vocab_count1: Counter()
+        :type vocab_count2: Counter()
+        :return: merged vocab count
+        """
+        return vocab_count1 + vocab_count2
+
     def _merge_words(self, other, merged_profile):
         """
         Merges the words of two TextProfiler profiles
@@ -169,15 +190,23 @@ class TextProfiler(object):
                           "since there were conflicting values for case "
                           "sensitivity between the two profiles being merged.")
 
-        
+        merged_profile._top_k_chars = None
+        if self._top_k_chars and other._top_k_chars:
+            merged_profile._top_k_chars = max(
+                self._top_k_chars, other._top_k_chars)
+
+        merged_profile._top_k_words = None
+        if self._top_k_words and other._top_k_words:
+            merged_profile._top_k_words = max(
+                self._top_k_words, other._top_k_words)
+
         BaseColumnProfiler._merge_calculations(merged_profile.__calculations,
                                  self.__calculations,
                                  other.__calculations)
 
         if "vocab" in merged_profile.__calculations:
-            merged_profile.vocab = self.vocab.copy()
-            merged_profile._update_vocab(other.vocab)
-            
+            merged_profile.vocab_count = self._merge_vocab(self.vocab_count,
+                                                           other.vocab_count)
         if "words" in merged_profile.__calculations:
             self._merge_words(other, merged_profile)
 
@@ -192,11 +221,18 @@ class TextProfiler(object):
 
         :return:
         """
+        top_k_words = self._top_k_words
+        if top_k_words is None:
+            top_k_words = len(self.word_count.keys())
+
         word_count = sorted(self.word_count.items(),
                             key=lambda x: x[1],
-                            reverse=True)
+                            reverse=True)[:top_k_words]
+
         profile = dict(
-            vocab=self.vocab,
+            vocab=list(self.vocab_count.keys()),
+            vocab_count=dict(
+                self.vocab_count.most_common(self._top_k_chars)),
             words=list(self.word_count.keys()),
             word_count=dict(word_count),
             times=self.times,
@@ -207,7 +243,7 @@ class TextProfiler(object):
     def _update_vocab(self, data, prev_dependent_properties=None,
                       subset_properties=None):
         """
-        Finds the unique vocabulary used in the text samples.
+        Finds the vocabulary counts used in the text samples.
 
         :param data: list or array of data from which to extract vocab
         :type data: Union[list, numpy.array, pandas.DataFrame]
@@ -220,7 +256,7 @@ class TextProfiler(object):
         :return: None
         """
         data_flat = list(itertools.chain(*data))
-        self.vocab = utils._combine_unique_sets(self.vocab, data_flat)
+        self.vocab_count += Counter(data_flat)
 
     @BaseColumnProfiler._timeit(name='words')
     def _update_words(self, data, prev_dependent_properties=None,
