@@ -3,6 +3,7 @@ from __future__ import absolute_import
 
 import os
 import unittest
+from io import BytesIO
 
 from dataprofiler.data_readers.data import Data
 from dataprofiler.data_readers.avro_data import AVROData
@@ -31,6 +32,17 @@ class TestAVRODataClass(unittest.TestCase):
             dict(path=os.path.join(test_dir, 'avro/snappy_compressed_intentionally_mislabeled_file.csv'), count=4),
         ]
 
+    def test_is_match_for_byte_streams(self):
+        """
+        Determine if the avro file can be automatically identified from
+        byte stream
+        """
+        for input_file in self.input_file_names:
+            # as BytesIO Stream
+            with open(input_file['path'], 'rb') as fp:
+                byte_string = BytesIO(fp.read())
+                self.assertTrue(AVROData.is_match(byte_string))
+
     def test_avro_file_identification(self):
         """
         Determine if the avro file can be automatically identified
