@@ -8,6 +8,7 @@ import six
 import pandas as pd
 import numpy as np
 
+from dataprofiler.profilers import utils
 from dataprofiler.profilers.data_labeler_column_profile import \
     DataLabelerColumn
 from dataprofiler.profilers.profiler_options import DataLabelerOptions
@@ -301,3 +302,60 @@ class TestDataLabelerColumnProfiler(unittest.TestCase):
                                     "sample size are not the same for both column "
                                     "profiles."):
             profiler3 = profiler + profiler2
+
+
+    def test_diff(self, mock_instance):
+        self._setup_data_labeler_mock(mock_instance)
+
+        profiler1 = DataLabelerColumn("")
+        profiler2 = DataLabelerColumn("")
+        
+        # Mock out the data_label, avg_predictions, and label_representation
+        # properties
+        with mock.patch("dataprofiler.profilers.data_labeler_column_profile"
+                        ".DataLabelerColumn.data_label"), \
+            mock.patch("dataprofiler.profilers.data_labeler_column_profile."
+                       "DataLabelerColumn.avg_predictions"),\
+            mock.patch("dataprofiler.profilers.data_labeler_column_profile."
+                       "DataLabelerColumn.label_representation"):
+            profiler1.data_label = "a|b|c"
+            profiler1.avg_predictions = {
+                "a": 0.25,
+                "b": 0.0,
+                "c": 0.75
+            }
+            profiler1.label_representation = {
+                "a": 0.15,
+                "b": 0.01,
+                "c": 0.84
+            }
+
+            profiler2.data_label = "b|c|d"
+            profiler2.avg_predictions = {
+                "a": 0.25,
+                "b": 0.70,
+                "c": 0.05
+            }
+            profiler2.label_representation = {
+                "a": 0.99,
+                "b": 0.01,
+                "c": 0.0
+            }
+
+            diff = profiler1.diff(profiler2)
+            expected_diff = {
+                "data_label": utils.find_diff_of_lists_and_sets(
+                    ['a', 'b', 'c'], ['b', 'c', 'd']),
+                "avg_predictions": {
+                    "a": "unchanged",
+                    "b": -0.70,
+                    "c": 0.70
+                },
+                "label_representation": {
+                    "a": -0.84,
+                    "b": "unchanged",
+                    "c": 0.84
+                }
+            }
+            self.maxDiff = None
+            self.assertDictEqual(expected_diff, diff)
