@@ -4,6 +4,8 @@ import os
 import unittest
 from unittest import mock
 
+import dataprofiler
+
 from . import test_utils
 
 from dataprofiler import Data, Profiler
@@ -29,6 +31,19 @@ class TestDataProfiler(unittest.TestCase):
                  type='csv'),
         ]
 
+    def test_set_seed(self):
+        import dataprofiler as dp
+        self.assertEqual(dp.settings._seed, None)
+
+        dp.set_seed(5)
+        self.assertEqual(dp.settings._seed, 5)
+
+        with self.assertRaisesRegex(ValueError, "Seed should be a non-negative integer."):
+            dp.set_seed(-5)
+
+        with self.assertRaisesRegex(ValueError, "Seed should be a non-negative integer."):
+            dp.set_seed(5.2)
+
     def test_data_import(self):
         for file in self.input_file_names:
             data = Data(file['path'])
